@@ -201,9 +201,6 @@ class cmt(make):
         '''
         Run the tests in a Gaudi/LHCb project using CMT.
         '''
-        # ensure that tests are not run in parallel
-        kwargs.pop('max_load', None)
-        kwargs.pop('jobs', None)
         env = kwargs.get('env', {})
         if 'CMTCONFIG' not in env:
             env['CMTCONFIG'] = (os.environ.get('CMTCONFIG')
@@ -333,10 +330,16 @@ class cmake_old(make):
         '''
         Run the tests in a Gaudi/LHCb project using CMT.
         '''
-        # ensure that tests are not run in parallel
-        kwargs.pop('max_load', None)
-        kwargs.pop('jobs', None)
         kwargs['args'] = ['BUILDDIR=build'] + kwargs.get('args', [])
+        if "jobs" in kwargs:
+            flag = "-j{}".format(kwargs.pop("jobs"))
+            for i, arg in enumerate(kwargs["args"]):
+                if arg.startswith("ARGS="):
+                    kwargs["args"][i] += " " + flag
+                    break
+            else:  # (this else matches the for) no ARGS= in args
+                kwargs["args"].append("ARGS={}".format(flag))
+
         output = [
             self._make(target, proj, **kwargs)
             for target in ('configure', 'test')
