@@ -109,78 +109,6 @@ _soft_db = _soft_db_singleton()
 del _soft_db_singleton
 
 
-def getpack(desc, recursive_head=None, export=False, protocol=None):
-    '''
-    Checkout the project described by the Project instance 'desc'.
-    '''
-    from os.path import normpath, join
-    log = __log__.getChild('getpack')
-    protocol = protocol or os.environ.get('GETPACK_PROTOCOL', 'anonymous')
-    getpack_cmd = [
-        'getpack', '--batch', '--no-config', '--no-eclipse', '--branches',
-        '--force', '--protocol', protocol
-    ]
-
-    if recursive_head is None:
-        recursive_head = desc.version == 'HEAD'
-
-    rootdir = os.curdir
-    prjroot = normpath(desc.baseDir)
-    from LbNightlyTools.Configuration import Project
-    if isinstance(desc, Project):
-        # we are checking out a project
-        cmd = getpack_cmd + ['-P', '-H' if recursive_head else '-r']
-    else:
-        # we are checking out a data package
-        cmd = getpack_cmd + ['-v']
-        if desc.container:
-            rootdir = desc.container.baseDir
-    if export:
-        cmd.append('--export')
-    cmd.extend([desc.name, desc.version])
-
-    if not os.path.exists(rootdir):
-        log.debug('creating %s', rootdir)
-        os.makedirs(rootdir)
-
-    log.debug('checking out %s', desc)
-    outputs = [retry_log_call(cmd, cwd=rootdir, retry=3)]
-
-    if hasattr(desc, 'overrides') and desc.overrides:
-        errors = False
-        log.debug('overriding packages')
-        for package, version in desc.overrides.items():
-            if version:
-                cmd = getpack_cmd + [package, version]
-                try:
-                    # ensure we do not get conflicts when changing version
-                    vers_cmt_file = join(prjroot, package, 'cmt',
-                                         'version.cmt')
-                    if os.path.exists(vers_cmt_file):
-                        # remove the file generated by getpack
-                        os.remove(vers_cmt_file)
-                        # ensure that the directory matches the svn state
-                        # (if version.cmt was actually under version control)
-                        log_call(['svn', 'revert', package], cwd=prjroot)
-                    outputs.append(retry_log_call(cmd, cwd=prjroot, retry=3))
-                except RuntimeError, x:
-                    log.warning(str(x))
-                    errors = True
-            else:
-                log.debug('removing %s', package)
-                outputs.append({
-                    'retcode': 0,
-                    'stdout': 'Removing %s\n' % package,
-                    'stderr': ''
-                })
-                shutil.rmtree(join(prjroot, package), ignore_errors=True)
-        if errors:
-            raise RuntimeError('problems handling overrides')
-
-    log.debug('checkout of %s completed in %s', desc, prjroot)
-    return _merge_outputs(outputs)
-
-
 def ignore(desc, export=False):
     '''
     Special checkout function used to just declare a project version in the
@@ -584,17 +512,19 @@ def git(proj, url=None, commit=None, export=False, merges=None):
     log = __log__.getChild('git')
 
     if not url:
-        from urlparse import urlsplit
-        uri = urlsplit(_soft_db.getSourceURI(proj.name, proj.version))
-        if not uri.scheme:
-            # we are asked to get a getpack project with git
-            path = 'LHCb-SVN-mirrors/' + proj.name
+        from .Configuration import Package
+        if isinstance(proj, Package):
+            gitlab_name = 'lhcb-datapkg/{}'.format(proj.name)
         else:
-            path = uri.path
-        url = 'https://gitlab.cern.ch/{0}.git'.format(path)
+            from urlparse import urlsplit
+            uri = urlsplit(_soft_db.getSourceURI(proj.name, proj.version))
+            if not uri.scheme:
+                # assume a sane default
+                gitlab_name = 'lhcb/' + proj.name
+            else:
+                gitlab_name = uri.path
+        url = 'https://gitlab.cern.ch/{}.git'.format(gitlab_name)
         inGitLab = True
-        gitlab_name = path
-        del path
     else:
         inGitLab = 'gitlab.cern.ch' in url
         gitlab_name = url.split('/', 3)[-1].replace('.git', '')
@@ -1000,41 +930,8 @@ def lbscripts(proj, url=None, export=False, merges=None, commit=None):
     return _merge_outputs(outputs)
 
 
-def default(proj, *args, **kwargs):
-    '''
-    Delegate to the correct method, depending on the project name and version.
-    '''
-    from Configuration import Package
-    if isinstance(proj, Package):
-        # packages are not yet in the database
-        url = kwargs.get('url')
-        if not url:
-            gitlab_name = 'lhcb-datapkg/{}'.format(proj.name)
-            if gitlabProjectExists(gitlab_name):
-                logging.debug('%s is in CERN Gitlab', proj.name)
-                kwargs['url'] = (
-                    'https://gitlab.cern.ch/{}.git').format(gitlab_name)
-                return git(proj, *args, **kwargs)
-            else:
-                logging.debug('could not find %s in CERN Gitlab', proj.name)
-        elif '.git' in url:
-            return git(proj, *args, **kwargs)
-        return getpack(proj, *args, **kwargs)
-
-    from urlparse import urlsplit
-    logging.debug('getting source URI from SoftDB')
-    uri = _soft_db.getSourceURI(proj.name, proj.version)
-    logging.debug('got %s', uri)
-
-    uri = urlsplit(uri)
-    if not uri.scheme:
-        return getpack(proj, *args, **kwargs)
-    elif uri.scheme == 'gitlab-cern':
-        if not args and 'url' not in kwargs:
-            kwargs['url'] = 'https://gitlab.cern.ch/{0.path}.git'.format(uri)
-        if 'commit' not in kwargs and proj.version != uri.fragment:
-            kwargs['commit'] = uri.fragment
-        return git(proj, *args, **kwargs)
+def default(*args, **kwargs):
+    return git(*args, **kwargs)
 
 
 def getMethod(method=None):
