@@ -663,9 +663,29 @@ class Project(object):
                 for proj in config.get('Project', 'dependencies').split(',')
             ]
 
+        def fromLHCbProjectYml():
+            '''
+            Helper to get the dependencies from a metadata file in the project,
+            called 'lhcbproject.yml'.
+            The file (in YAML) must contain a `dependencies` field as a list of
+            strings
+
+            E.g.::
+
+                ---
+                name: MyProject
+                dependencies:
+                  - ProjectA
+                  - ProjectB
+            '''
+            import yaml
+            return yaml.safe_load(
+                open(os.path.join(proj_root,
+                                  "lhcbproject.yml")))['dependencies']
+
         # Try all the helpers until one succeeds
         deps = []
-        for helper in (fromCMake, fromCMT, fromProjInfo):
+        for helper in (fromCMake, fromCMT, fromLHCbProjectYml, fromProjInfo):
             try:
                 deps = helper()
                 break
