@@ -625,6 +625,27 @@ class PeriodicTestMsg(object):
             self.log.warning('problems sending message: %s: %s',
                              type(x).__name__, x)
 
+        try:
+            token_fn = os.path.join(
+                os.environ.get("PRIVATE_DIR",
+                               os.path.join(os.environ['HOME'], 'private')),
+                "lbtaskrun_token_notify_nightly_built",
+            )
+            with open(token_fn, "rt") as fp:
+                token = fp.read().strip()
+
+            import requests
+            r = requests.put(
+                "https://lhcb-core-tasks.web.cern.ch/hooks/build-ready/ci/%s/%s/%s/%s/"
+                % (self.slot.name, self.slot.build_id, msg['project'].name,
+                   self.platform),
+                headers={"Authorization": "Bearer %s" % token},
+            )
+            r.raise_for_status()
+        except Exception as e:
+            self.log.exception(
+                "Failed to send build ready message to lbtaskweb")
+
     def accept(self, msg):
         '''
         Implements the receiver side of the message protocol.
