@@ -526,11 +526,19 @@ class Script(PlainScript):
             dest='no_build_dir',
             help='do extract "build" directories from (binary) tarfiles')
 
+        parser.add_option(
+            "-j",
+            "--jobs",
+            help=
+            "number of parallel download+unpack jobs to use [default: -1, all CPUs]"
+        )
+
         parser.set_defaults(
             artifacts_root=ARTIFACTS_URL,
             flavour='nightly',
             no_git=False,
-            no_build_dir=True)
+            no_build_dir=True,
+            jobs="-1")
 
     def main(self):
         from joblib import Parallel, delayed
@@ -668,7 +676,7 @@ class Script(PlainScript):
                 return status, result
 
             installed = {}
-            for status, result in Parallel(n_jobs=-1)(
+            for status, result in Parallel(n_jobs=int(opts.jobs) or 1)(
                     delayed(do_install)(f) for f in required_files):
                 if status:
                     installed[result[0]] = result[1]
